[![GitHub version](https://badge.fury.io/gh/wohe157%2Fplogpro.svg)](https://badge.fury.io/gh/wohe157%2Fplogpro)
[![PyPI version](https://badge.fury.io/py/plogpro.svg)](https://badge.fury.io/py/plogpro)

[![Documentation status](https://readthedocs.org/projects/plogpro/badge/?version=latest)](https://plogpro.readthedocs.io/en/latest/?badge=latest)
![Test results](https://github.com/wohe157/plogpro/actions/workflows/unittest.yml/badge.svg)
[![Coverage](https://codecov.io/gh/wohe157/plogpro/branch/main/graph/badge.svg?token=wr6EfOLLJu)](https://codecov.io/gh/wohe157/plogpro)

# Plogpro
A simple and versatile Python package for logging, profiling and more.

## Instalation
Plogpro is available on PyPI and can be installed through pip with:
```
pip install plogpro
```

## Documentation
Documentation is available [here](https://plogpro.readthedocs.io/en/stable/) via
Read the Docs. Refer to the stable version for the latest published version, or
to the latest version for the most up-to-date documentation with the Github
repository, which might contain functionality that is not yet published.
